@@ -35,7 +35,6 @@ describe 'basic neutron' do
         allow_overlapping_ips => true,
         core_plugin           => 'ml2',
         debug                 => true,
-        verbose               => true,
         service_plugins => [
           'neutron.services.l3_router.l3_router_plugin.L3RouterPlugin',
           'neutron_lbaas.services.loadbalancer.plugin.LoadBalancerPlugin',
@@ -53,6 +52,9 @@ describe 'basic neutron' do
         auth_password       => 'a_big_secret',
         identity_uri        => 'http://127.0.0.1:35357/',
         sync_db             => true,
+        service_providers   => [
+          'LOADBALANCER:Haproxy:neutron_lbaas.services.loadbalancer.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default',
+        ],
       }
       class { '::neutron::client': }
       class { '::neutron::quota': }
@@ -73,9 +75,6 @@ describe 'basic neutron' do
         mechanism_drivers    => ['openvswitch', 'sriovnicswitch']
       }
       class { '::neutron::agents::ml2::sriov': }
-      class { '::neutron::services::lbaas':
-        service_providers => 'LOADBALANCER:Haproxy:neutron_lbaas.services.loadbalancer.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default',
-      }
       class { '::neutron::services::lbaas::haproxy': }
       class { '::neutron::services::lbaas::octavia': }
       EOS
