@@ -19,7 +19,8 @@ describe 'neutron::agents::dhcp' do
       :dhcp_driver              => 'neutron.agent.linux.dhcp.Dnsmasq',
       :root_helper              => 'sudo neutron-rootwrap /etc/neutron/rootwrap.conf',
       :enable_isolated_metadata => false,
-      :enable_metadata_network  => false }
+      :enable_metadata_network  => false,
+      :purge_config             => false }
   end
 
   let :test_facts do
@@ -78,6 +79,12 @@ describe 'neutron::agents::dhcp' do
       is_expected.to contain_service('neutron-dhcp-service').that_subscribes_to('Package[neutron]')
     end
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('neutron_dhcp_agent_config').with({
+        :purge => false
+      })
+    end
+
     context 'with manage_service as false' do
       before :each do
         params.merge!(:manage_service => false)
@@ -135,15 +142,6 @@ describe 'neutron::agents::dhcp' do
       end
     end
 
-    context 'with use_namespaces as false' do
-      before :each do
-        params.merge!(:use_namespaces => false)
-      end
-      it 'should set use_namespaces option' do
-        is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/use_namespaces').with_value(p[:use_namespaces])
-      end
-    end
-
     context 'when availability zone is set' do
       before :each do
         params.merge!(:availability_zone => 'zone1')
